ServiceTable

Struct ServiceTable 

pub struct ServiceTable<M>
where M: Sized + Clone + Tvf,
{ /* private fields */ }
Strucure that define the service table which contain information to how contact a processor for a given service name

Implementations

Source

impl<M> ServiceTable<M>
where M: Sized + Clone + Tvf,

pub fn is_empty(&self) -> bool

Getter to know if the service table is empty

pub fn len(&self) -> usize

Getter of the length of the service table (use for metrics)

pub fn exist_proc_service(&self, name: &str) -> bool

Method to know if the service is available from a processor

Call by the processor to know if a service is available (service test)

pub fn get_proc_service(&self, name: &str) -> Option<&ProcService<M>>

Method to get a processor that respond to the service

Call by the processor to send a transaction to a processor that give the corresponding service

pub fn add_service(&mut self, name: &str, proc_service: ProcService<M>)

Method to add a service to the table

Can be call only by the main task to modify the service table

pub fn remove_service_proc(&mut self, name: &str, proc_id: u32)

Method to remove whole processor service from the table

Can be call only by the main task to modify the service table

pub fn remove_service(&mut self, name: &str, proc_id: u32, queue_id: u32)

Method to remove a service from the table

Can be call only by the main task to modify the service table

pub fn remove_proc_services(&mut self, proc_id: u32)

Method to remove all services from a given processor from the table

Can be call only by the main task to modify the service table

pub fn remove_proc_queue_services(&mut self, proc_id: u32, queue_id: u32)

Method to remove all services from a given processor queue from the table

Can be call only by the main task to modify the service table