pub struct ProsaConfig { /* private fields */ }Expand description
Loaded ProSA configuration.
Implementations
Sourceimpl ProsaConfig
impl ProsaConfig
Sourcepub fn from_path(config_path: &str) -> Result<Self, ConfigError>
pub fn from_path(config_path: &str) -> Result<Self, ConfigError>
Load a ProSA configuration from a file or directory path.
Sourcepub fn from_config(config: Config) -> Result<Self, ConfigError>
pub fn from_config(config: Config) -> Result<Self, ConfigError>
Create a ProSA configuration wrapper and load all processor adaptor configs.
Sourcepub fn try_deserialize<C>(&self) -> Result<C, ConfigError>where
C: DeserializeOwned,
pub fn try_deserialize<C>(&self) -> Result<C, ConfigError>where
C: DeserializeOwned,
Deserialize the full configuration.
Sourcepub fn get_proc<C>(&self, proc: &impl ProcBusParam) -> Result<C, ConfigError>where
C: DeserializeOwned,
pub fn get_proc<C>(&self, proc: &impl ProcBusParam) -> Result<C, ConfigError>where
C: DeserializeOwned,
Deserialize a processor configuration from its processor name.
Sourcepub fn get_adaptor_config(&self, proc: &impl ProcBusParam) -> Option<&Config>
pub fn get_adaptor_config(&self, proc: &impl ProcBusParam) -> Option<&Config>
Access a processor adaptor configuration from its processor name.
Sourcepub fn watch_paths(&self, config_path: &str) -> Vec<PathBuf>
pub fn watch_paths(&self, config_path: &str) -> Vec<PathBuf>
Return every configuration path watched to maintain this configuration.
Sourcepub fn has_proc_changed(&self, new: &Self, proc_config_key: &str) -> bool
pub fn has_proc_changed(&self, new: &Self, proc_config_key: &str) -> bool
Check if one processor configuration differs from another loaded configuration.