ReceiverU16

Struct ReceiverU16 

pub struct ReceiverU16<T, const N: usize> { /* private fields */ }
Available on crate feature queue only.
Receives values from the associated Sender.

Implementations

Source

impl<T, const N: usize> ReceiverU16<T, N>

pub async fn recv(&self) -> T

Receives the next value for this receiver.

use std::ops::Add;
use tokio::time::{Duration, Instant};
use prosa::event::queue::{QueueChecker, timed};

#[tokio::main]
async fn main() {
    let (mut tx, rx) = timed::channel_spmc_u16::<i32, 4096>();
    assert!(tx.is_empty());
    assert_eq!(Ok(()), tx.try_send(0, Instant::now().add(Duration::from_millis(200))));

    // If the element hasn't been consumed and it's not expired, you should get it
    assert_eq!(0, rx.recv().await);
}
pub fn try_recv(&self) -> Result<Option<T>, QueueError<T>>

Tries to receive the next value for this receiver.

If the queue is empty, it return Err(QueueError::Empty) If the element can’t be pulled because of synchronicity, it return Ok(None)

use std::ops::Add;
use tokio::time::{Duration, Instant};
use prosa::event::queue::{QueueChecker, timed};

let (mut tx, rx) = timed::channel_spmc_u16::<i32, 4096>();
assert!(tx.is_empty());
assert_eq!(Ok(()), tx.try_send(0, Instant::now().add(Duration::from_millis(200))));

// The try_recv method return an Ok
// But can return either `Ok(Some(0))` or `Ok(None)` depending on internal atomic
assert!(rx.try_recv().is_ok());