SenderU16

Struct SenderU16 

pub struct SenderU16<T, const N: usize> { /* private fields */ }
Available on crate feature queue only.
Sends values to the associated Receiver.

Implementations

Source

impl<T, const N: usize> SenderU16<T, N>

pub async fn send( &mut self, value: T, timeout: Instant, ) -> Result<(), SendError<T>>

Sends a value, waiting until there is capacity.

use std::ops::Add;
use tokio::time::{Duration, Instant};
use prosa::event::queue::{QueueChecker, timed};

#[tokio::main]
async fn main() {
   let (mut tx, _rx) = timed::channel_spmc_u16::<i32, 4096>();
    assert!(tx.is_empty());
    assert_eq!(Ok(()), tx.send(0, Instant::now().add(Duration::from_millis(200))).await);
}
pub fn try_send( &mut self, value: T, timeout: Instant, ) -> Result<(), SendError<T>>

Try to send a value, return an Full error if the queue is full

use std::ops::Add;
use tokio::time::{Duration, Instant};
use prosa::event::queue::{QueueChecker, timed};

let (mut tx, _rx) = timed::channel_spmc_u16::<i32, 4096>();
assert!(tx.is_empty());
assert_eq!(Ok(()), tx.try_send(0, Instant::now().add(Duration::from_millis(200))));
pub async fn timeout(&mut self) -> Option<T>

Method to retrieve expired message sent in the queue.

use std::ops::Add;
use tokio::time::{Duration, Instant, sleep};
use prosa::event::queue::timed;

#[tokio::main]
async fn main() {
   let (mut tx, _rx) = timed::channel_spmc_u16::<i32, 4096>();

    tx.send(1, Instant::now().add(Duration::from_millis(10))).await;

    // The data is not consumed during that time

    assert_eq!(Some(1), tx.timeout().await);
}