Regulator

Struct Regulator 

pub struct Regulator { /* private fields */ }
Transaction regulator use to asynchronously regulate flow to fixed TPS

use std::time::Duration;
use tokio::sync::mpsc;
use prosa::event::speed::Regulator;

async fn queue_regulation(regulator: &mut Regulator, tx: mpsc::Sender<u16>, mut rx: mpsc::Receiver<u16>) {
    tokio::select! {
        _ = rx.recv() => {
            // Specify a response time if you have it to avoid spamming a sick receiver
            regulator.notify_receive_transaction(Duration::default());
        }
        _ = regulator.tick() => {
            // Can send a transaction
            tx.send(1234);
            regulator.notify_send_transaction();
        }
    };
}

Implementations

Source

impl Regulator

pub fn new( max_speed: f64, timeout_threshold: Duration, max_concurrents_send: u32, speed_interval: u16, ) -> Regulator

Create a new regulator with:

  • Maximum TPS speed
  • Threshold time before sending the next request if the distant respond a timeout (to not overload the distant)
  • Maximum concurents request in parallel
  • Number of interval used to know TPS rate (15 by default)
pub async fn tick(&mut self)

Method to synchronize regulator sending rate

pub fn notify_send_transaction(&mut self)

Indicate that a new transaction have been sent

pub fn notify_receive_transaction(&mut self, response_time: Duration)

Indicate that we receive a response to a sended transaction

pub fn add_tick_overhead(&mut self, overhead: Duration)

Add an overhead to the tick duration if the tick need to be delayed

pub fn get_speed(&self) -> f64

Getter of the current speed of transaction flow