pub struct ServiceTable<M>{ /* private fields */ }Expand description
Strucure that define the service table which contain information to how contact a processor for a given service name
Implementations
Sourceimpl<M> ServiceTable<M>
impl<M> ServiceTable<M>
Sourcepub fn exist_proc_service(&self, name: &str) -> bool
pub fn exist_proc_service(&self, name: &str) -> bool
Method to know if the service is available from a processor
Call by the processor to know if a service is available (service test)
Sourcepub fn get_proc_service(&self, name: &str) -> Option<&ProcService<M>>
pub fn get_proc_service(&self, name: &str) -> Option<&ProcService<M>>
Method to get a processor that respond to the service
Call by the processor to send a transaction to a processor that give the corresponding service
Sourcepub fn add_service(&mut self, name: &str, proc_service: ProcService<M>)
pub fn add_service(&mut self, name: &str, proc_service: ProcService<M>)
Method to add a service to the table
Can be call only by the main task to modify the service table
Sourcepub fn remove_service_proc(&mut self, name: &str, proc_id: u32)
pub fn remove_service_proc(&mut self, name: &str, proc_id: u32)
Method to remove whole processor service from the table
Can be call only by the main task to modify the service table
Sourcepub fn remove_service(&mut self, name: &str, proc_id: u32, queue_id: u32)
pub fn remove_service(&mut self, name: &str, proc_id: u32, queue_id: u32)
Method to remove a service from the table
Can be call only by the main task to modify the service table
Sourcepub fn remove_proc_services(&mut self, proc_id: u32)
pub fn remove_proc_services(&mut self, proc_id: u32)
Method to remove all services from a given processor from the table
Can be call only by the main task to modify the service table
Sourcepub fn remove_proc_queue_services(&mut self, proc_id: u32, queue_id: u32)
pub fn remove_proc_queue_services(&mut self, proc_id: u32, queue_id: u32)
Method to remove all services from a given processor queue from the table
Can be call only by the main task to modify the service table